@@ -1,4 +1,4 @@
-from obschart.api.node import Node
+from ..node import Node
 
 imageFragment = """
 fragment Image on Image {
