@@ -46,10 +46,12 @@ class BlocksActionBuilder(object):
             }
         )
 
-    # export type BlocksActionMultipleChoiceFieldBlock = $ReadOnly<{|
-    #   ...BlocksActionFieldBlockBase<'multipleChoiceField'>,
-    #   choices: Array<{| title: string |}>,
-    # |}>;
+    def add_multiple_choice_field(
+        self, title: str, required: bool = False, choices: list = [],
+    ):
+        return self.add_block(
+            {"type": "scaleField", "title": title, "required": required, "choices": choices,}
+        )
 
     def add_number_field(
         self, title: str, required: bool = False, min: int = 0, max: int = 10, step: int = 1,
